Enum WriteError
#[non_exhaustive]pub enum WriteError {
TooLarge,
BufferFull,
Encode(EncodeError),
}Expand description
Error returned by PacketWriter::write.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TooLarge
The packet’s encoded size exceeds the configured maximum packet size: a client must not send a packet larger than the server’s Maximum Packet Size (3.2.2.3.6).
BufferFull
The fixed-capacity output buffer cannot hold the packet.
Encode(EncodeError)
Encoding failed. This indicates a bug, as the buffer is sized to the
packet’s encoded_len.